@@ -20,6 +20,7 @@ import zope.interface
 
 log = logging.getLogger(__name__)
 
+
 class CollmexDialect(csv.Dialect):
     quoting = csv.QUOTE_ALL
     delimiter = ';'
@@ -76,7 +77,8 @@ class CollmexDataManager(object):
     def tpc_abort(self, transaction):
         assert transaction is self._transaction
         if self.voted:
-            raise Exception('Single phase data manager: cannot abort after vote')
+            raise Exception(
+                'Single phase data manager: cannot abort after vote')
         self._reset()
 
     def tpc_finish(self, transaction):
@@ -84,7 +86,8 @@ class CollmexDataManager(object):
         self._reset()
 
     def sortKey(self):
-        # XXX make very small or add single-phase datamanager integration to the transaction module.
+        # XXX make very small or add single-phase datamanager integration to
+        # the transaction module.
         return None
 
 
@@ -174,6 +177,16 @@ class Collmex(object):
             self.company_id,
             customer_id)
 
+    def get_activities(self):
+        # XXX there is currently no API function for this call!
+        import gocept.collmex.testing
+        browser = gocept.collmex.testing.collmex_login()
+        browser.getLink('Verwaltung').click()
+        browser.getLink('Exportieren').click()
+        browser.getControl('tigkeiten').click()
+        browser.getControl('Daten exportieren').click()
+        return browser.contents
+
     def _get_cache(self):
         self._ensure_local_attribute('cache')
         if self._local.cache is None:
