@@ -3,6 +3,7 @@
 # See also LICENSE.txt
 
 import UserDict
+import datetime
 import gocept.collmex.interfaces
 import zope.interface
 
@@ -32,13 +33,27 @@ class Model(object, UserDict.UserDict):
     def __iter__(self):
         for field in self.fields:
             if field in self:
-                value = self[field]
-                if isinstance(value, unicode):
-                    value = value.encode('Windows-1252')
-                yield value
+                yield self._convert(self[field])
             else:
                 yield gocept.collmex.interfaces.NULL
 
+    @property
+    def company(self):
+        return self['Firma Nr']
+
+    @company.setter
+    def company(self, company_id):
+        self['Firma Nr'] = company_id
+
+    def _convert(self, value):
+        if isinstance(value, datetime.date):
+            return value.strftime('%Y%m%d')
+        elif isinstance(value, datetime.time):
+            return value.strftime('%H:%M')
+        elif isinstance(value, unicode):
+            value = value.encode('Windows-1252')
+        return value
+
 
 def factory(record_type):
     """looks up Model class representing the given `record_type`."""
@@ -231,3 +246,57 @@ class Product(Model):
         'Lohnkosten-Bezugsmenge',
         'Reserviert',
     )
+
+    @property
+    def company(self):
+        return self['Firma']
+
+    @company.setter
+    def company(self, company_id):
+        self['Firma'] = company_id
+
+
+class Activity(Model):
+
+    zope.interface.implements(gocept.collmex.interfaces.IActivity)
+
+    satzart = 'CMXACT'
+    fields = (
+        'Satzart',
+        'Projekt Nr',
+        'Mitarbeiter Nr',
+        'Firma Nr',
+        'Satz Nr',
+        'Beschreibung',
+        'Datum',
+        'Von',
+        'Bis',
+        'Pausen',
+    )
+
+
+class Project(Model):
+
+    zope.interface.implements(gocept.collmex.interfaces.IProject)
+
+    satzart = 'CMXPRJ'
+    fields = (
+        'Satzart',
+        'Projektnummer',
+        'Firma Nr',
+        'Bezeichnung',
+        'Kunde Nr',
+        'Name des Kunden',
+        'Abgeschlossen',
+        'Reserviert',
+        'Reserviert',
+        'Reserviert',
+        'Reserviert',
+        'Reserviert',
+        'Satz Nr',
+        'Satz Bezeichnung',
+        'Produktnummer',
+        'Satz',
+        'Währung',
+        'Mengeneinheit',
+    )
